@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 77 2011-12-23 23:09:47Z yablacky $
+# $Id: smsconlib.py 86 2011-12-25 14:52:38Z yablacky $
 ##############################################################
 
 # standard modules
@@ -21,7 +21,7 @@ def getSysBuildNameAndVersion(defaultName, defaultVersion = '999.1', headerInfo
     Analyze information from version control system to find out name and version of a branch.
     @param string defaultName Name to return if version information not recognized.
     @param string defaultVersion Version to return if version information not recognized.
-    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.6/src/opt/smscon/smsconlib.py 77 2011-12-23 23:09:47Z yablacky $ keyword to be analyzed.
+    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.7/src/opt/smscon/smsconlib.py 86 2011-12-25 14:52:38Z yablacky $ keyword to be analyzed.
     @param int dirLevel Number of extra dirs to walk up to find the one that contains version information (0 = parent dir).
     @return list (name, version) The name and version information.
     """
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.6/src/opt/smscon/smsconlib.py 77 2011-12-23 23:09:47Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.7/src/opt/smscon/smsconlib.py 86 2011-12-25 14:52:38Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -46,6 +46,7 @@ InstPath    = '/opt/%s' % NAME
 if XDEBUG: InstPath = '.'
 BootPath    = '/etc/event.d'
 DaemonFile  = '%s_daemon' % NAME
+CommandFile = '%s_cmds' % NAME
 CodeFile    = '%s_code' % NAME
 ConfigFile  = '%s_config' % NAME
 BootFile    = '%s_boot' % NAME
@@ -133,7 +134,7 @@ def pidof(ProcessName):
     if PIDs != '':
         return PIDs
     PIDs = []
-    for psLine in os.popen('ps|grep -v grep|grep %s' % shellArg(ProcessName)).readlines():
+    for psLine in os.popen('ps -ef|grep -v grep|grep %s' % shellArg(' ' + ProcessName)).readlines():
         PIDs.append(psLine.split()[0])
     return ' '.join(PIDs)
 
@@ -882,6 +883,7 @@ class smscon_daemon:
     """
     TELL_RELOAD    = signal.SIGINT
     TELL_TERMINATE = signal.SIGTERM
+    TELL_COMMAND   = signal.SIGHUP
 
     def runs(self):
         """
